"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const _1 = require("./");
class ActiveWebhooks {
    constructor() {
        this.workflowWebhooks = {};
        this.webhookUrls = {};
        this.testWebhooks = false;
    }
    async add(webhookData, mode) {
        if (webhookData.workflow.id === undefined) {
            throw new Error('Webhooks can only be added for saved workflows as an id is needed!');
        }
        if (this.workflowWebhooks[webhookData.workflow.id] === undefined) {
            this.workflowWebhooks[webhookData.workflow.id] = [];
        }
        this.webhookUrls[this.getWebhookKey(webhookData.httpMethod, webhookData.path)] = webhookData;
        const webhookExists = await webhookData.workflow.runWebhookMethod('checkExists', webhookData, _1.NodeExecuteFunctions, mode, this.testWebhooks);
        if (webhookExists === false) {
            await webhookData.workflow.runWebhookMethod('create', webhookData, _1.NodeExecuteFunctions, mode, this.testWebhooks);
        }
        await webhookData.workflow.runNodeHooks('activate', webhookData, _1.NodeExecuteFunctions, mode);
        this.workflowWebhooks[webhookData.workflow.id].push(webhookData);
    }
    get(httpMethod, path) {
        const webhookKey = this.getWebhookKey(httpMethod, path);
        if (this.webhookUrls[webhookKey] === undefined) {
            return undefined;
        }
        return this.webhookUrls[webhookKey];
    }
    getWebhookKey(httpMethod, path) {
        return `${httpMethod}|${path}`;
    }
    async removeByWorkflowId(workflowId) {
        if (this.workflowWebhooks[workflowId] === undefined) {
            return false;
        }
        const webhooks = this.workflowWebhooks[workflowId];
        const mode = 'internal';
        for (const webhookData of webhooks) {
            await webhookData.workflow.runWebhookMethod('delete', webhookData, _1.NodeExecuteFunctions, mode, this.testWebhooks);
            await webhookData.workflow.runNodeHooks('deactivate', webhookData, _1.NodeExecuteFunctions, mode);
            delete this.webhookUrls[this.getWebhookKey(webhookData.httpMethod, webhookData.path)];
        }
        delete this.workflowWebhooks[workflowId];
        return true;
    }
    async removeAll() {
        const workflowIds = Object.keys(this.workflowWebhooks);
        const removePromises = [];
        for (const workflowId of workflowIds) {
            removePromises.push(this.removeByWorkflowId(workflowId));
        }
        await Promise.all(removePromises);
        return;
    }
}
exports.ActiveWebhooks = ActiveWebhooks;
//# sourceMappingURL=ActiveWebhooks.js.map